@@ -4,12 +4,12 @@ UrlLink for Contact Message
 from __future__ import annotations
 
 from typing import (
-    Type,
-    Union
+    Optional,
+    Type
 )
 import requests
-from lxml import etree  # type: ignore
-from wechaty_puppet import UrlLinkPayload, get_logger  # type: ignore
+from lxml import etree
+from wechaty_puppet import UrlLinkPayload, get_logger
 
 log = get_logger('UrlLink')
 
@@ -32,21 +32,24 @@ class UrlLink:
     @classmethod
     def create(
         cls: Type[UrlLink],
-        url: str, title: Union[str, None], thumbnail_url: Union[str, None], description: Union[str, None]
+        url: str, title: Optional[str], thumbnail_url: Optional[str], description: Optional[str]
     ) -> UrlLink:
         """
         create urllink from url string
         """
         log.info('create url_link for %s', url)
         html = etree.HTML(requests.get(url).text)
-        if title is None:
+        if not title:
             title = html.xpath('//meta[@property="og:title"]/@content')
+            assert title is not None
             title = title[0] if len(title) else url
-        if thumbnail_url is None:
+        if not thumbnail_url:
             thumbnail_url = html.xpath('//meta[@property="og:image"]/@content')
-            thumbnailUrl = thumbnail_url[0] if len(thumbnail_url) else ""
-        if description is None:
+            assert thumbnail_url is not None
+            thumbnail_url = thumbnail_url[0] if len(thumbnail_url) else ""
+        if not description:
             description = html.xpath('//meta[@property="og:description"]/@content')
+            assert description is not None
             description = description[0] if len(description) else ""
         payload = UrlLinkPayload(
             title=title,
@@ -56,7 +59,7 @@ class UrlLink:
         )
         return UrlLink(payload)
 
-    def __str__(self):
+    def __str__(self) -> str:
         """
         UrlLink string format output
         :return:
